@@ -1,7 +1,8 @@
 import os
-from nose.tools import *
+# from nose.tools import *
 import pandas as pd
 import unittest
+from .utils import raises
 
 import py_entitymatching as em
 
@@ -586,19 +587,19 @@ class OverlapBlockerTestCases(unittest.TestCase):
         validate_data(D, expected_ids_2)
 
     def test_ob_block_tuples_whitespace(self):
-        assert_equal(self.ob.block_tuples(self.A.loc[1], self.B.loc[2],
+        self.assertEqual(self.ob.block_tuples(self.A.loc[1], self.B.loc[2],
                                           l_overlap_attr_1, r_overlap_attr_1),
                      False)
-        assert_equal(self.ob.block_tuples(self.A.loc[2], self.B.loc[2],
+        self.assertEqual(self.ob.block_tuples(self.A.loc[2], self.B.loc[2],
                                           l_overlap_attr_1, r_overlap_attr_1),
                      True)
 
     def test_ob_block_tuples_qgram(self):
-        assert_equal(self.ob.block_tuples(self.A.loc[1], self.B.loc[2],
+        self.assertEqual(self.ob.block_tuples(self.A.loc[1], self.B.loc[2],
                                           l_overlap_attr_1, r_overlap_attr_1,
                                           q_val=3, word_level=False),
                      False)
-        assert_equal(self.ob.block_tuples(self.A.loc[0], self.B.loc[0],
+        self.assertEqual(self.ob.block_tuples(self.A.loc[0], self.B.loc[0],
                                           l_overlap_attr_1, r_overlap_attr_1,
                                           q_val=3, word_level=False),
                      True)
@@ -612,16 +613,16 @@ class OverlapBlockerTestCases(unittest.TestCase):
         em.set_key(A, 'ID')
         B = em.read_csv_metadata(path_b)
         em.set_key(B, 'ID')
-        assert_equal(self.ob.block_tuples(A.loc[1], B.loc[3], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[1], B.loc[3], l_overlap_attr_1,
                                           r_overlap_attr_1, allow_missing=True),
                      False)
-        assert_equal(self.ob.block_tuples(A.loc[3], B.loc[2], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[3], B.loc[2], l_overlap_attr_1,
                                           r_overlap_attr_1, allow_missing=True),
                      False)
-        assert_equal(self.ob.block_tuples(A.loc[3], B.loc[3], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[3], B.loc[3], l_overlap_attr_1,
                                           r_overlap_attr_1, allow_missing=True),
                      False)
-        assert_equal(self.ob.block_tuples(A.loc[2], B.loc[2], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[2], B.loc[2], l_overlap_attr_1,
                                           r_overlap_attr_1, allow_missing=True),
                      True)
 
@@ -634,11 +635,11 @@ class OverlapBlockerTestCases(unittest.TestCase):
         em.set_key(A, 'ID')
         B = em.read_csv_metadata(path_b)
         em.set_key(B, 'ID')
-        assert_equal(self.ob.block_tuples(A.loc[1], B.loc[3], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[1], B.loc[3], l_overlap_attr_1,
                                           r_overlap_attr_1), True)
-        assert_equal(self.ob.block_tuples(A.loc[3], B.loc[2], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[3], B.loc[2], l_overlap_attr_1,
                                           r_overlap_attr_1), True)
-        assert_equal(self.ob.block_tuples(A.loc[3], B.loc[3], l_overlap_attr_1,
+        self.assertEqual(self.ob.block_tuples(A.loc[3], B.loc[3], l_overlap_attr_1,
                                           r_overlap_attr_1), True)
 
 
@@ -716,29 +717,32 @@ class OverlapBlockerMulticoreTestCases(unittest.TestCase):
 def validate_metadata(C, l_output_attrs=None, r_output_attrs=None,
                       l_output_prefix='ltable_', r_output_prefix='rtable_',
                       l_key='ID', r_key='ID'):
+    tc = unittest.TestCase()
     s1 = ['_id', l_output_prefix + l_key, r_output_prefix + r_key]
     if l_output_attrs:
         s1 += [l_output_prefix + x for x in l_output_attrs if x != l_key]
     if r_output_attrs:
         s1 += [r_output_prefix + x for x in r_output_attrs if x != r_key]
     s1 = sorted(s1)
-    assert_equal(s1, sorted(C.columns))
-    assert_equal(em.get_key(C), '_id')
-    assert_equal(em.get_property(C, 'fk_ltable'), l_output_prefix + l_key)
-    assert_equal(em.get_property(C, 'fk_rtable'), r_output_prefix + r_key)
+    tc.assertEqual(s1, sorted(C.columns))
+    tc.assertEqual(em.get_key(C), '_id')
+    tc.assertEqual(em.get_property(C, 'fk_ltable'), l_output_prefix + l_key)
+    tc.assertEqual(em.get_property(C, 'fk_rtable'), r_output_prefix + r_key)
 
 def validate_data(C, expected_ids=None):
+    tc = unittest.TestCase()
     if expected_ids:
         lid = em.get_property(C, 'fk_ltable')
         rid = em.get_property(C, 'fk_rtable')
         C_ids = C[[lid, rid]].set_index([lid, rid])
         actual_ids = sorted(C_ids.index.values.tolist())
-        assert_equal(expected_ids, actual_ids)
+        tc.assertEqual(expected_ids, actual_ids)
     else:
-        assert_equal(len(C), 0)
+        tc.assertEqual(len(C), 0)
 
 def validate_metadata_two_candsets(C, D):
-    assert_equal(sorted(C.columns), sorted(D.columns))
-    assert_equal(em.get_key(D), em.get_key(C))
-    assert_equal(em.get_property(D, 'fk_ltable'), em.get_property(C, 'fk_ltable'))
-    assert_equal(em.get_property(D, 'fk_rtable'), em.get_property(C, 'fk_rtable'))
+    tc = unittest.TestCase()
+    tc.assertEqual(sorted(C.columns), sorted(D.columns))
+    tc.assertEqual(em.get_key(D), em.get_key(C))
+    tc.assertEqual(em.get_property(D, 'fk_ltable'), em.get_property(C, 'fk_ltable'))
+    tc.assertEqual(em.get_property(D, 'fk_rtable'), em.get_property(C, 'fk_rtable'))
